==> cx88-1.2.2.tar.gz: cx88-1.2.2/common/cx88_regs.h <==
/*-
 * Copyright 2007 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_REGS_H__
#define __CX88_REGS_H__

// Miscellaneous registers (all functions)

// Source/destination burst threshold
#define CX23880_REG_DMA_SRC_THRESH        0x200000
#define CX23880_REG_DMA_DST_THRESH        0x200010
#define CX23880_THRESH_ISB                0xF,8
#define CX23880_THRESH_PCI                0xF,0

// DMA source target address
#define CX23880_REG_DMA_SRC_TARGET        0x200004

// DMA destination target address
#define CX23880_REG_DMA_DST_TARGET        0x200014

// DMA source SRAM address
#define CX23880_REG_DMA_SRC_SRAM          0x200008

// DMA destination SRAM address
#define CX23880_REG_DMA_DST_SRAM          0x200018

// Source/destsination DMA control
#define CX23880_REG_SRC_DMAC              0x20000C
#define CX23880_REG_DST_DMAC              0x20001C
#define CX23880_DMAC_RISC                 (1 << 19)
#define CX23880_DMAC_FUNC                 7,16
#define CX23880_DMAC_COUNT                0xFFFF,0

// PCI subsystem PID/VID load
#define CX23880_REG_SUBSYS_LOAD           0x200030
#define CX23880_SUBPID_LOAD               0xFFFF,16
#define CX23880_SUBVID_LOAD               0xFFFF,0

// Device control #2
#define CX23880_REG_DEVCNTL2              0x200034
#define CX23885_REG_DEVCNTL2              0x40000
#define CX88_RUN_RISC                     (1 << 5)

// CX23880 PCI interrupt mask/status
#define CX23880_REG_PCI_INTMASK           0x200040
#define CX23880_REG_PCI_INTSTAT           0x200044
#define CX23880_REG_PCI_INTMSTAT          0x200048
#define CX23880_PCI_INT_GPIO23            (1 << 20)
#define CX23880_PCI_INT_GPIO22            (1 << 19)
#define CX23880_PCI_INT_GPIO16_SAMP       (1 << 18)
#define CX23880_PCI_INT_I2C_ACK           (1 << 17)
#define CX23880_PCI_INT_I2C_DONE          (1 << 16)
#define CX23880_PCI_INT_IPB_DMA_BERR      (1 << 15)
#define CX23880_PCI_INT_DST_BERR          (1 << 14)
#define CX23880_PCI_INT_SRC_BERR          (1 << 13)
#define CX23880_PCI_INT_BRIDGE_BERR       (1 << 12)
#define CX23880_PCI_INT_RISCW_BERR        (1 << 11)
#define CX23880_PCI_INT_RISCR_BERR        (1 << 10)
#define CX23880_PCI_INT_DST_DMA_CMPL      (1 << 9)
#define CX23880_PCI_INT_SRC_DMA_CMPL      (1 << 8)
#define CX23880_PCI_INT_TIMER             (1 << 7)
#define CX23880_PCI_INT_GPHOST            (1 << 4)
#define CX23880_PCI_INT_VIP               (1 << 3)
#define CX23880_PCI_INT_MPEGTS            (1 << 2)
#define CX23880_PCI_INT_AUDIO             (1 << 1)
#define CX23880_PCI_INT_VIDEO             (1 << 0)

// CX23885/7 PCI interrupt mask/status
#define CX23885_REG_PCI_INTMASK           0x40010
#define CX23885_REG_PCI_INTSTAT           0X40014
#define CX23885_REG_PCI_INTMSTAT          0x40018
#define CX23885_PCI_INT_I2C2_ACK          (1 << 21)
#define CX23885_PCI_INT_I2C2_DONE         (1 << 20)
#define CX23885_PCI_INT_I2C1_ACK          (1 << 19)
#define CX23885_PCI_INT_I2C1_DONE         (1 << 18)
#define CX23885_PCI_INT_I2C0_ACK          (1 << 17)
#define CX23885_PCI_INT_I2C0_DONE         (1 << 16)
#define CX23885_PCI_INT_AUDIO_EXT         (1 << 4)
#define CX23885_PCI_INT_AUDIO_INT         (1 << 3)
#define CX23885_PCI_INT_VIDEO_C           (1 << 2)
#define CX23885_PCI_INT_VIDEO_B           (1 << 1)
#define CX23885_PCI_INT_VIDEO_A           (1 << 0)

// PLL
#define CX23880_REG_PLL                   0x35C008
#define CX23880_PLL_LOCKED                (1 << 27)
#define CX23880_PLL_DDS                   (1 << 26)
#define CX23880_PLL_CLOCK                 3,24
#define CX23880_PLL_CLOCK_SLOW            0
#define CX23880_PLL_CLOCK_FAST            1
#define CX23880_PLL_PRESCALE              3,22
#define CX23880_PLL_PRESCALE2             0
#define CX23880_PLL_PRESCALE5             1
#define CX23880_PLL_PRESCALE4             2
#define CX23880_PLL_PRESCALE3             3
#define CX23880_PLL_INT_DIVIDE            0x3F,16
#define CX23880_PLL_FRAC_DIVIDE           0xFFFF,0

// GPIO
#define CX23880_REG_GPIO0                 0x350010
#define CX23880_REG_GPIO1                 0x350014
#define CX23880_REG_GPIO2                 0x350018
#define CX23880_REG_GPIO3                 0x35001C
#define CX23880_GPIO_24BIT                (1 << 25)
#define CX23880_GPIO_24BIT_IO             0xFFFFFF,0
#define CX23880_GPIO_BIT_WRITE            0xFF,16
#define CX23880_GPIO_OUT_ENABLE           0xFF,8
#define CX23880_GPIO_IO                   0xFF,0

#define CX23885_REG_GPIO                  0x110010
#define CX23885_GPIO_LINE_MASK            0xFFFF,16
#define CX23885_GPIO_IO                   0xFFFF,0

#define CX23885_REG_MC_RWD                0x110020
#define CX23885_REG_MC_OEN                0x110024
#define CX23885_MC_WRITE                  (1 << 15)
#define CX23885_MC_READ                   (1 << 14)
#define CX23885_MC_CHIP_SEL               (1 << 13)
#define CX23885_MC_READY                  (1 << 12)
#define CX23885_MC_ADDR                   0xF,8
#define CX23885_MC_ADDR_MEM_DATA0         0
#define CX23885_MC_ADDR_MEM_DATA1         1
#define CX23885_MC_ADDR_MEM_DATA2         2
#define CX23885_MC_ADDR_MEM_DATA3         3
#define CX23885_MC_ADDR_MEM_ADDR2         4
#define CX23885_MC_ADDR_MEM_ADDR1         5
#define CX23885_MC_ADDR_MEM_ADDR0         6
#define CX23885_MC_ADDR_REG_DATA0         8
#define CX23885_MC_ADDR_REG_DATA1         9
#define CX23885_MC_ADDR_REG_DATA2         10
#define CX23885_MC_ADDR_REG_DATA3         11
#define CX23885_MC_ADDR_REG_ADDR0         12
#define CX23885_MC_ADDR_REG_ADDR1         13
#define CX23885_MC_ADDR_REG_MODE          14
#define CX23885_MC_DATA                   0xFF,0
#define CX23885_MC_DATA_REG_READ          0x0
#define CX23885_MC_DATA_MEM_READ          0x0
#define CX23885_MC_DATA_REG_WRITE         0x1
#define CX23885_MC_DATA_MEM_WRITE         0x40                
#define CX23885_REG_MC_CTL                0x110028
#define CX23885_MC_CTL_SPEED              0x3,5
#define CX23885_MC_SPEED_SLOW             0x1
#define CX23885_MC_SPEED_NORMAL           0x0
#define CX23885_MC_SPEED_FAST             0x3
#define CX23885_MC_CTL_GPIO_SEL           0x3,1
#define CX23885_MC_GPIO_SEL_GPIO0         0x0
#define CX23885_MC_GPIO_SEL_GPIO1         0x1
#define CX23885_MC_GPIO_SEL_GPIO2         0x2
#define CX23885_MC_GPIO_SEL_GPIO3         0x3
#define CX23885_MC_CTL_GPIO_ENABLE        0x1

// GPIO interrupt sensitivity
#define CX23880_REG_GPIO_ISM              0x350028
#define CX23885_REG_GPIO_ISM              0x110014
#define CX88_GPIO23_ISM_EDGE              (1 << 3)
#define CX88_GPIO22_ISM_EDGE              (1 << 2)
#define CX88_GPIO23_POS_POL               (1 << 1)
#define CX88_GPIO22_POS_POL               (1 << 0)

// Lower 32 bits of timer
#define CX23880_REG_TIMER_LOW32           0x35C034

// Upper 16 bits of timer
#define CX23880_REG_TIMER_HI16            0x35C038
#define CX23880_TIMER_HI16                0xFFFF,0

// Lower 32 bits of timer limit
#define CX23880_REG_TLIM_LOW32            0x35C03C

// Upper 16 bits of timer limit
#define CX23880_REG_TLIM_HI16             0x35C040
#define CX23880_TLIM_DIV4                 (1 << 31)
#define CX23880_TLIM_HI16                 0xFFFF,0

// PINMUX I/O
#define CX23880_REG_PINMUX_IO             0x35C044
#define CX23880_PINMUX_MPEG_PAR           (1 << 7)
#define CX23880_PINMUX_VIP_MODE           3,5
#define CX23880_PINMUX_VIP_GPIO           0
#define CX23880_PINMUX_VIP_VHAD           1
#define CX23880_PINMUX_VIP_VIP2           2
#define CX23880_PINMUX_VID_SYNC           (1 << 4)
#define CX23880_PINMUX_VID8_OUT           (1 << 3)
#define CX23880_PINMUX_VID10_OUT          (1 << 2)
#define CX23880_PINMUX_VID_IN             (1 << 1)
#define CX23880_PINMUX_HCS1               (1 << 0)

// ADC configuration
#define CX23880_REG_ADC_CONFIG            0x35C04C
#define CX23880_AUDIO_DAC_POWERDOWN       (1 << 4)
#define CX23880_LUMA_ADC_POWERDOWN        (1 << 3)
#define CX23880_CHROMA_ADC_POWERDOWN      (1 << 2)
#define CX23880_ADC_BG_POWERDOWN          (1 << 1)
#define CX23880_CHROMA_VIDEO              (1 << 0)

// Peripheral reset
#define CX23880_REG_SRST                  0x35C05C
#define CX23880_SRST_OUT                  (1 << 0)

// Software reset of internal state
#define CX23885_REG_SOFT_RESET            0x11001C

// Miscellaneous configuration
#define CX23885_REG_CFG0                  0x50000
#define CX23885_REG_CFG1                  0x50004
#define CX23885_REG_CFG2                  0x50008
#define CX23885_REG_TLCTL0                0x50318

#endif

==> cx88-1.3.0.tar.gz: cx88-1.3.0/common/cx88_regs.h <==
/*-
 * Copyright 2007 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __CX88_REGS_H__
#define __CX88_REGS_H__

// Miscellaneous registers (all functions)

// Source/destination burst threshold
#define CX23880_REG_DMA_SRC_THRESH        0x200000
#define CX23880_REG_DMA_DST_THRESH        0x200010
#define CX23880_THRESH_ISB                0xF,8
#define CX23880_THRESH_PCI                0xF,0

// DMA source target address
#define CX23880_REG_DMA_SRC_TARGET        0x200004

// DMA destination target address
#define CX23880_REG_DMA_DST_TARGET        0x200014

// DMA source SRAM address
#define CX23880_REG_DMA_SRC_SRAM          0x200008

// DMA destination SRAM address
#define CX23880_REG_DMA_DST_SRAM          0x200018

// Source/destsination DMA control
#define CX23880_REG_SRC_DMAC              0x20000C
#define CX23880_REG_DST_DMAC              0x20001C
#define CX23880_DMAC_RISC                 (1 << 19)
#define CX23880_DMAC_FUNC                 7,16
#define CX23880_DMAC_COUNT                0xFFFF,0

// PCI subsystem PID/VID load
#define CX23880_REG_SUBSYS_LOAD           0x200030
#define CX23880_SUBPID_LOAD               0xFFFF,16
#define CX23880_SUBVID_LOAD               0xFFFF,0

// Device control #2
#define CX23880_REG_DEVCNTL2              0x200034
#define CX23885_REG_DEVCNTL2              0x40000
#define CX88_RUN_RISC                     (1 << 5)

// CX23880 PCI interrupt mask/status
#define CX23880_REG_PCI_INTMASK           0x200040
#define CX23880_REG_PCI_INTSTAT           0x200044
#define CX23880_REG_PCI_INTMSTAT          0x200048
#define CX23880_PCI_INT_GPIO23            (1 << 20)
#define CX23880_PCI_INT_GPIO22            (1 << 19)
#define CX23880_PCI_INT_GPIO16_SAMP       (1 << 18)
#define CX23880_PCI_INT_I2C_ACK           (1 << 17)
#define CX23880_PCI_INT_I2C_DONE          (1 << 16)
#define CX23880_PCI_INT_IPB_DMA_BERR      (1 << 15)
#define CX23880_PCI_INT_DST_BERR          (1 << 14)
#define CX23880_PCI_INT_SRC_BERR          (1 << 13)
#define CX23880_PCI_INT_BRIDGE_BERR       (1 << 12)
#define CX23880_PCI_INT_RISCW_BERR        (1 << 11)
#define CX23880_PCI_INT_RISCR_BERR        (1 << 10)
#define CX23880_PCI_INT_DST_DMA_CMPL      (1 << 9)
#define CX23880_PCI_INT_SRC_DMA_CMPL      (1 << 8)
#define CX23880_PCI_INT_TIMER             (1 << 7)
#define CX23880_PCI_INT_GPHOST            (1 << 4)
#define CX23880_PCI_INT_VIP               (1 << 3)
#define CX23880_PCI_INT_MPEGTS            (1 << 2)
#define CX23880_PCI_INT_AUDIO             (1 << 1)
#define CX23880_PCI_INT_VIDEO             (1 << 0)

// CX23885/7 PCI interrupt mask/status
#define CX23885_REG_PCI_INTMASK           0x40010
#define CX23885_REG_PCI_INTSTAT           0x40014
#define CX23885_REG_PCI_INTMSTAT          0x40018
#define CX23885_PCI_INT_I2C2_ACK          (1 << 21)
#define CX23885_PCI_INT_I2C2_DONE         (1 << 20)
#define CX23885_PCI_INT_I2C1_ACK          (1 << 19)
#define CX23885_PCI_INT_I2C1_DONE         (1 << 18)
#define CX23885_PCI_INT_I2C0_ACK          (1 << 17)
#define CX23885_PCI_INT_I2C0_DONE         (1 << 16)
#define CX23885_PCI_INT_AUDIO_EXT         (1 << 4)
#define CX23885_PCI_INT_AUDIO_INT         (1 << 3)
#define CX23885_PCI_INT_VIDEO_C           (1 << 2)
#define CX23885_PCI_INT_VIDEO_B           (1 << 1)
#define CX23885_PCI_INT_VIDEO_A           (1 << 0)

// PLL
#define CX23880_REG_PLL                   0x35C008
#define CX23880_PLL_LOCKED                (1 << 27)
#define CX23880_PLL_DDS                   (1 << 26)
#define CX23880_PLL_CLOCK                 3,24
#define CX23880_PLL_CLOCK_SLOW            0
#define CX23880_PLL_CLOCK_FAST            1
#define CX23880_PLL_PRESCALE              3,22
#define CX23880_PLL_PRESCALE2             0
#define CX23880_PLL_PRESCALE5             1
#define CX23880_PLL_PRESCALE4             2
#define CX23880_PLL_PRESCALE3             3
#define CX23880_PLL_INT_DIVIDE            0x3F,16
#define CX23880_PLL_FRAC_DIVIDE           0xFFFF,0

// GPIO
#define CX23880_REG_GPIO0                 0x350010
#define CX23880_REG_GPIO1                 0x350014
#define CX23880_REG_GPIO2                 0x350018
#define CX23880_REG_GPIO3                 0x35001C
#define CX23880_GPIO_24BIT                (1 << 25)
#define CX23880_GPIO_24BIT_IO             0xFFFFFF,0
#define CX23880_GPIO_BIT_WRITE            0xFF,16
#define CX23880_GPIO_OUT_ENABLE           0xFF,8
#define CX23880_GPIO_IO                   0xFF,0

#define CX23885_REG_GPIO                  0x110010
#define CX23885_GPIO_LINE_MASK            0xFFFF,16
#define CX23885_GPIO_IO                   0xFFFF,0

#define CX23885_REG_MC_RWD                0x110020
#define CX23885_REG_MC_OEN                0x110024
#define CX23885_MC_WRITE                  (1 << 15)
#define CX23885_MC_READ                   (1 << 14)
#define CX23885_MC_CHIP_SEL               (1 << 13)
#define CX23885_MC_READY                  (1 << 12)
#define CX23885_MC_ADDR                   0xF,8
#define CX23885_MC_ADDR_MEM_DATA0         0
#define CX23885_MC_ADDR_MEM_DATA1         1
#define CX23885_MC_ADDR_MEM_DATA2         2
#define CX23885_MC_ADDR_MEM_DATA3         3
#define CX23885_MC_ADDR_MEM_ADDR2         4
#define CX23885_MC_ADDR_MEM_ADDR1         5
#define CX23885_MC_ADDR_MEM_ADDR0         6
#define CX23885_MC_ADDR_REG_DATA0         8
#define CX23885_MC_ADDR_REG_DATA1         9
#define CX23885_MC_ADDR_REG_DATA2         10
#define CX23885_MC_ADDR_REG_DATA3         11
#define CX23885_MC_ADDR_REG_ADDR0         12
#define CX23885_MC_ADDR_REG_ADDR1         13
#define CX23885_MC_ADDR_REG_MODE          14
#define CX23885_MC_DATA                   0xFF,0
#define CX23885_MC_DATA_REG_READ          0x0
#define CX23885_MC_DATA_MEM_READ          0x0
#define CX23885_MC_DATA_REG_WRITE         0x1
#define CX23885_MC_DATA_MEM_WRITE         0x40                
#define CX23885_REG_MC_CTL                0x110028
#define CX23885_MC_CTL_SPEED              0x3,5
#define CX23885_MC_SPEED_SLOW             0x1
#define CX23885_MC_SPEED_NORMAL           0x0
#define CX23885_MC_SPEED_FAST             0x3
#define CX23885_MC_CTL_GPIO_SEL           0x3,1
#define CX23885_MC_GPIO_SEL_GPIO0         0x0
#define CX23885_MC_GPIO_SEL_GPIO1         0x1
#define CX23885_MC_GPIO_SEL_GPIO2         0x2
#define CX23885_MC_GPIO_SEL_GPIO3         0x3
#define CX23885_MC_CTL_GPIO_ENABLE        0x1

// GPIO interrupt sensitivity
#define CX23880_REG_GPIO_ISM              0x350028
#define CX23885_REG_GPIO_ISM              0x110014
#define CX88_GPIO23_ISM_EDGE              (1 << 3)
#define CX88_GPIO22_ISM_EDGE              (1 << 2)
#define CX88_GPIO23_POS_POL               (1 << 1)
#define CX88_GPIO22_POS_POL               (1 << 0)

// Lower 32 bits of timer
#define CX23880_REG_TIMER_LOW32           0x35C034

// Upper 16 bits of timer
#define CX23880_REG_TIMER_HI16            0x35C038
#define CX23880_TIMER_HI16                0xFFFF,0

// Lower 32 bits of timer limit
#define CX23880_REG_TLIM_LOW32            0x35C03C

// Upper 16 bits of timer limit
#define CX23880_REG_TLIM_HI16             0x35C040
#define CX23880_TLIM_DIV4                 (1 << 31)
#define CX23880_TLIM_HI16                 0xFFFF,0

// PINMUX I/O
#define CX23880_REG_PINMUX_IO             0x35C044
#define CX23880_PINMUX_MPEG_PAR           (1 << 7)
#define CX23880_PINMUX_VIP_MODE           3,5
#define CX23880_PINMUX_VIP_GPIO           0
#define CX23880_PINMUX_VIP_VHAD           1
#define CX23880_PINMUX_VIP_VIP2           2
#define CX23880_PINMUX_VID_SYNC           (1 << 4)
#define CX23880_PINMUX_VID8_OUT           (1 << 3)
#define CX23880_PINMUX_VID10_OUT          (1 << 2)
#define CX23880_PINMUX_VID_IN             (1 << 1)
#define CX23880_PINMUX_HCS1               (1 << 0)

// ADC configuration
#define CX23880_REG_ADC_CONFIG            0x35C04C
#define CX23880_AUDIO_DAC_POWERDOWN       (1 << 4)
#define CX23880_LUMA_ADC_POWERDOWN        (1 << 3)
#define CX23880_CHROMA_ADC_POWERDOWN      (1 << 2)
#define CX23880_ADC_BG_POWERDOWN          (1 << 1)
#define CX23880_CHROMA_VIDEO              (1 << 0)

// Peripheral reset
#define CX23880_REG_SRST                  0x35C05C
#define CX23880_SRST_OUT                  (1 << 0)

// Software reset of internal state
#define CX23885_REG_SOFT_RESET            0x11001C

// Miscellaneous configuration
#define CX23885_REG_CFG0                  0x50000
#define CX23885_REG_CFG1                  0x50004
#define CX23885_REG_CFG2                  0x50008
#define CX23885_REG_TLCTL0                0x50318

#endif
